@@ -1,8 +1,5 @@
 test_that("Report for local", {
   skip_on_cran()
-  skip_on_os("mac")
-  skip_on_os("linux")
-  skip_on_os("solaris")
 
   test_f <- res_example
   # Full
@@ -23,9 +20,6 @@ test_that("Report for local", {
 
 test_that("Report for url", {
   skip_on_cran()
-  skip_on_os("mac")
-  skip_on_os("linux")
-  skip_on_os("solaris")
 
   test_f <- res_example
   # Full
